function [ABAR,BBAR,CBAR,M,NNO,NNC]=ctrbobsvf(A,B,C,tol)
%
% [ABAR,BBAR,CBAR,M,NNO,NNC]=CTRBOBSVF(A,B,C) or
% [ABAR,BBAR,CBAR,M,NNO,NNC]=CTRBOBSVF(A,B,C,TOL) return a Schur
% realization with a block-diagonal structure:
%   * a first block (NNOxNMO) associated with inobservable dynamics,
%   * a second block associated with the minimal dynamics,
%   * a third block (NNCxNNC) associated with uncontrolable dynamics.
%
% TOL is a tolerance for rank computation (default: 1e-6).
%
% M is a unitary matrix such that: ABAR = M' * A * M;
%  

%   D. Alazard  01/99
%   

if nargin==3,tol=1e-6;end;
n=size(A,1);

% Inobservable sub-block:
[a1,b1,c1,pass1,k1]=obsvf(A,B,C,tol);
no=sum(k1);
NNO=n-no;
Ano=a1(1:NNO,1:NNO);Ao=a1(NNO+1:n,NNO+1:n);
Bo=b1(NNO+1:n,:);
Co=c1(:,NNO+1:n);
% Schur Decomposition of Ano:
[u1,t1]=schur(Ano);
[u1,t1]=rsf2csf(u1,t1);

% Incontrollable sub-blaock in Ao:
[a2,b2,c2,pass2,k2]=ctrbf(Ao,Bo,Co,tol);
nc=sum(k2);
NNC=no-nc;
Anc=a2(1:NNC,1:NNC);Ac=a2(NNC+1:no,NNC+1:no);
% Schur Decomposition of Anc:
[u2,t2]=schur(Anc);
[u2,t2]=rsf2csf(u2,t2);

% Schur Decomposition of Ac:
[u3,t3]=schur(Ac);
[u3,t3]=rsf2csf(u3,t3);

% Variable change matrix
permut=[zeros(NNC,nc) eye(NNC,NNC);eye(nc,nc) zeros(nc,NNC)];
M=pass1' * daug(u1,pass2') * daug(eye(NNO,NNO),permut*daug(u3,u2));
ABAR=M'*A*M;
BBAR=M'*B;
CBAR=C*M;
