function [COR] = obr2cor2ddl(plant,K,G,Q,xr,ur);
% COR=OBR2COR2DDL(PLANT,K,G,Q,Xr,Ur) 
% compute the state space realization of the 2 degree-of-freedom 
% observer-based controller COR defined by the Youla 
% parameterization:
%    - K: state feedback gain, 
%    - G: state estimation gain, 
%    - Q: dynamic Youla parameter,
%  (this parameterization concern the plant defined by PLANT)
%    - Xr, Ur are the plant state and input equilibrium condition
%      to reach.
%
% Inputs of COR are measurement (y) and reference input (e= the new
% equilibrium point).
%
% PLANT,Q and SYS_K are defined as SS objects.
% (continous and discrete time cases are considered).
%
% Let us note: [A,B,C,D,Ts]=ssdata(PLANT), then the controller 
% realization is:
%                                                  _____
%             _____________________________________| Ur|___
%             |   ________________________         |___|  |
%             |  |                        |               |
%            +|+ | A-BK-GC+GDK | G | B-GD |               | 
%         u <-0--|     -K      | 0 |   I  |<----- y       |  
%    y-yhat /----|    -C+DK    | I |  -D  |<---0<--|K*Xr|-o- e
%           |    |________________________|  + |+  
%           |                                  |
%           |               ___________        |
%           |              |           |       |
%           \------------->| Q(s or z) |-------/
%                          |___________|
%
% Remark :  * continuous-time formulation (or predictor form in
%             discrete-time) for the state estimator
%           * positive feeedback
%
% See also: COR2OBR, COR2OBRA, OBR2COR

% D. Alazard 01/2012


[a,b,c,d,Ts]=ssdata(plant);
[p,m]=size(d);
if nargin==5, ur=zeros(m,1);end;
COR=obr2cor2ddl(plant,K,G,Q,K*xr);
COR=ss(COR.a,COR.b,COR.c,COR.d+[zeros(size(COR.D)-[0 1]) ur]);

