function OBRout=obr2obr(OBRin,T)
% OBR2OBR Change of state coordinates for observer-based realizations
% 
% OBRout=OBR2OBR(OBRin,T) performs a the similarity transformation z = Tx on 
%   the state vector x of the state-space model OBRin.mod and the
%   corresponding state-feedback gain OBRin.Kc, state-estimator gain
%   OBRin.Kf and transformation OBRin.M of the observer-based realization
%   OBRin.obr. That is:
%       OBRout.mod=ss2ss(OBRin.mod,T);
%       OBRout.Kc=OBRin.Kc*inv(T);
%       OBRout.Kf=T*OBRin.Kf;
%       OBRout.Q=OBRin.Q;
%       OBRout.obr=obr2cor(OBRout.mod,OBRout.Kc,OBRout.Kf,OBRout.Q);
%       OBRout.M=OBRin.M*daug(inv(T),eye(size(OBRin.Q.a,1)));
%
% see also:  COR2OBR, COR2OBRA, COR2TFG, COR2TFGA, OBR2COR
OBRout.mod=ss2ss(OBRin.mod,T);
OBRout.Kc=OBRin.Kc*inv(T);
OBRout.Kf=T*OBRin.Kf;
OBRout.Q=OBRin.Q;
OBRout.obr=obr2cor(OBRout.mod,OBRout.Kc,OBRout.Kf,OBRout.Q);
OBRout.M=OBRin.M*daug(inv(T),eye(size(OBRin.Q.a,1)));