function [SFdyn,SEdyn,Qdyn]=obrmap(OBR)
%
% OBRMAP(OBR) plots the closed-loop eigenvalues map 
% of the  system OBR.mod in positive feedback
% with the observer-based controller defined by the 
% Youla parameterization (OBR.Kc, OBR.Kf,
% OBR.Q) associated with OBR.mod:
%     - Kc: state feedback gain, 
%     - Kf: state estimation gain, 
%     - Q: (ss) dynamic Youla parameter.
%
% The structured input argument OBR can be the output of the
% function COR2OBRA (for instance).
%
% On the map, are marked:
% (considering [A,B,C,D,Ts]=ssdata(OBR.mod))
%     - state feedback dynamics: spec(A-B*Kc) (blue o),
%     - state estimation dynamics: spec(A-Kf*C) (red o),
%     - Youla parameter dynamics:  spec(Q.a) (green o).
% and also :
%     - open-loop plant dynamics: spec(A) (blue +),
%     - open-loop controller dynamics: (green +).
%
% Remark: * continuous-time formulation (or predictor form in
% discrete-time) for the state estimator
%
% [SFDYN,SEDYN,QDYN]=OBRMAP(OBR) does not open a graphics
% window but returns:
%   * SFDYN: state feedback dynamics: spec(A-B*K),
%   * SEDYN: state estimation dynamics: spec(A-G*C),
%   * QDYN: Youla parameter dynamics spec(Q.a);
%
% see also:  COR2OBR, COR2OBRA, COR2TFG, COR2TFGA, OBR2COR

% D. Alazard /01/01/99

[A,B,C,D,Ts]=ssdata(OBR.mod);
K=OBR.Kc;G=OBR.Kf;Q=ss(OBR.Q);
[p,m]=size(D);
SYS_K=ss([A-B*K-G*C+G*D*K],[G B-G*D],[-K;-C+D*K],...
         [0*ones(m,p) eye(m,m);eye(p,p) -D],Ts);
SYS_K=lft(SYS_K,Q);

vbf=eig(feedback(OBR.mod,-SYS_K));
SFdyn=eig(A-B*K);
SEdyn=eig(A-G*C);
Qdyn=eig(Q.a);
if nargout==0,
    va=eig(A);
    vak=eig(SYS_K.a);
    figure
    plot(real(vbf),imag(vbf),'kx');
    hold on
    plot(real(SFdyn),imag(SFdyn),'bo','LineWidth',2);
    plot(real(SEdyn),imag(SEdyn),'ro','LineWidth',2);
    plot(real(Qdyn),imag(Qdyn),'go','LineWidth',2);
    plot(real(va),imag(va),'b+','LineWidth',2);
    plot(real(vak),imag(vak),'g+','LineWidth',2);
    if OBR.mod.Ts==0, sgrid; else zgrid;end;
    zoom on
end

